CREATE TABLE IF NOT EXISTS `slider` ( 
`id_slider` int(11) NOT NULL AUTO_INCREMENT,
`code` varchar(255) CHARACTER SET utf8 NOT NULL,
`name` varchar(255) CHARACTER SET utf8 NOT NULL,
`is_image` tinyint(1),
`image_w` varchar(255) CHARACTER SET utf8,
`image_h` varchar(255) CHARACTER SET utf8,
`is_title` tinyint(1),
`is_description` tinyint(1),
`is_link` tinyint(1),
`view_order` int(11),
`template` varchar(255) CHARACTER SET utf8 NOT NULL,
PRIMARY KEY (`id_slider`) 
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;

CREATE TABLE IF NOT EXISTS `slider_slide` ( 
`id_slider_slide` int(11) NOT NULL AUTO_INCREMENT,
`id_slider` int(11),
`image` varchar(255) CHARACTER SET utf8 NOT NULL,
`title` varchar(255) CHARACTER SET utf8 NOT NULL,
`description` text NOT NULL,
`link` varchar(255) CHARACTER SET utf8 NOT NULL,
`view_order` int(11),
`active` tinyint(1),
PRIMARY KEY (`id_slider_slide`) 
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;
